@@ -130,7 +130,7 @@ class MessageSignedBase(MessageBase):
             elif self.body:
                 # Convert the plain text body to html.
                 logger.info('HTML body was not found, attempting to generate from plain text body.')
-                correctedBody = html.escpae(self.body).replace('\r', '').replace('\n', '</br>')
+                correctedBody = html.escpae(self.body).replace('\r', '').replace('\n', '<br />')
                 self._htmlBody = f'<html><body>{correctedBody}</body></head>'.encode('utf-8')
             else:
                 logger.info('HTML body could not be found nor generated.')
